# Changelog

## 0.1.1 (2025-03-17)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/OpenExecProtocol/oxp-python/compare/v0.1.0...v0.1.1)

### Bug Fixes

* **ci:** remove publishing patch ([#12](https://github.com/OpenExecProtocol/oxp-python/issues/12)) ([2910bc2](https://github.com/OpenExecProtocol/oxp-python/commit/2910bc21d18ae16a8cc999f8553d35eb7d4773d1))

## 0.1.0 (2025-03-17)

Full Changelog: [v0.0.2...v0.1.0](https://github.com/OpenExecProtocol/oxp-python/compare/v0.0.2...v0.1.0)

### Features

* CI fix ([43570f3](https://github.com/OpenExecProtocol/oxp-python/commit/43570f3352ea7cd28250e63f6efd87287bd7923e))


### Bug Fixes

* **ci:** ensure pip is always available ([#10](https://github.com/OpenExecProtocol/oxp-python/issues/10)) ([4594515](https://github.com/OpenExecProtocol/oxp-python/commit/4594515bd8c5500adfa6f6c511e86490b314426d))

## 0.0.2 (2025-03-15)

Full Changelog: [v0.0.1-alpha.1...v0.0.2](https://github.com/OpenExecProtocol/oxp-python/compare/v0.0.1-alpha.1...v0.0.2)

### Features

* **api:** update via SDK Studio ([#5](https://github.com/OpenExecProtocol/oxp-python/issues/5)) ([10b7707](https://github.com/OpenExecProtocol/oxp-python/commit/10b770743b760ccc9b7a806fbebcd6d6c5eab9e9))

## 0.0.1-alpha.1 (2025-03-15)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/OpenExecProtocol/oxp-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* go live ([#1](https://github.com/OpenExecProtocol/oxp-python/issues/1)) ([f34fa80](https://github.com/OpenExecProtocol/oxp-python/commit/f34fa8031bcf789d102f6292c480eb42a3c145ce))
* update SDK settings ([#3](https://github.com/OpenExecProtocol/oxp-python/issues/3)) ([3b8297b](https://github.com/OpenExecProtocol/oxp-python/commit/3b8297ba07fcdd5231f1f96ac25e8acc2d328d99))
